@@ -1,26 +1,7 @@
-{-
-Copyright (C) 2005-2006 John Goerzen <jgoerzen@complete.org>
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-
--}
-
 {- |
    Module     : Database.HDBC
-   Copyright  : Copyright (C) 2005-2009 John Goerzen
-   License    : GNU LGPL, version 2.1 or above
+   Copyright  : Copyright (C) 2005-2011 John Goerzen
+   License    : BSD3
 
    Maintainer : John Goerzen <jgoerzen@complete.org>
    Stability  : provisional
@@ -89,9 +70,6 @@ module Database.HDBC
 
      -- * Threading
      -- $threading
-
-     -- * Copyright and License
-     -- $legal
     )
 
 where
@@ -257,23 +235,3 @@ However, there are some caveats to the above:
    Details of thread support should be documented in the HDBC
    driver for each specific database.
 -}
-
-{- $legal
-Copyright (C) 2005-2009 John Goerzen <jgoerzen@complete.org>
-
-This library is free software; you can redistribute it and\/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) any later version.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
-
-You should have received a copy of the GNU Lesser General Public
-License along with this library; if not, write to the Free Software
-Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-
-Please see COPYING in the source distribution for the full license.
--}
